aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSuman Kumar <suman@inforcecomputing.com>2013-08-23 21:10:52 +0530
committerNicolas Dechesne <nicolas.dechesne@linaro.org>2014-05-06 17:48:46 -0700
commitfd533e6c7a1cdfcea0e9c347b2b7ed3e59b8e545 (patch)
tree18d9a32bff29b08cd6181d25c82c7da684a572f6
parent149c5280a99bb68735763f993df797768f439b04 (diff)
lvds: Revert: Reverted few changes from 8064T patch to make LVDS working
Change-Id: I1c22977f79985473638016207c6a2ee0b4856767
-rwxr-xr-xarch/arm/mach-msm/board-8064-regulator.c34
1 files changed, 19 insertions, 15 deletions
diff --git a/arch/arm/mach-msm/board-8064-regulator.c b/arch/arm/mach-msm/board-8064-regulator.c
index bbf67e2d027a..15fde682e2dd 100755
--- a/arch/arm/mach-msm/board-8064-regulator.c
+++ b/arch/arm/mach-msm/board-8064-regulator.c
@@ -443,7 +443,8 @@ VREG_CONSUMERS(BOOST) = {
.pin_ctrl = _pin_ctrl, \
}
-#define GPIO_VREG(_id, _reg_name, _gpio_label, _gpio, _supply_regulator) \
+#define GPIO_VREG(_id, _reg_name, _gpio_label, _gpio, _supply_regulator, \
+ _active_low) \
[GPIO_VREG_ID_##_id] = { \
.init_data = { \
.constraints = { \
@@ -457,8 +458,8 @@ VREG_CONSUMERS(BOOST) = {
.regulator_name = _reg_name, \
.gpio_label = _gpio_label, \
.gpio = _gpio, \
- }
-
+ .active_low = _active_low, \
+ }
#define SAW_VREG_INIT(_id, _name, _min_uV, _max_uV) \
{ \
@@ -572,14 +573,15 @@ VREG_CONSUMERS(BOOST) = {
/* GPIO regulator constraints */
struct gpio_regulator_platform_data
apq8064_gpio_regulator_pdata[] __devinitdata = {
- /* ID vreg_name gpio_label gpio supply */
- GPIO_VREG(EXT_5V, "ext_5v", "ext_5v_en", PM8921_MPP_PM_TO_SYS(7), NULL),
+ /* ID vreg_name gpio_label gpio supply active_low */
+ GPIO_VREG(EXT_5V, "ext_5v", "ext_5v_en",
+ PM8921_MPP_PM_TO_SYS(7), NULL, 0),
GPIO_VREG(EXT_3P3V, "ext_3p3v", "ext_3p3v_en",
- APQ8064_EXT_3P3V_REG_EN_GPIO, NULL),
+ APQ8064_EXT_3P3V_REG_EN_GPIO, NULL, 0),
GPIO_VREG(EXT_TS_SW, "ext_ts_sw", "ext_ts_sw_en",
- PM8921_GPIO_PM_TO_SYS(23), "ext_3p3v"),
+ PM8921_GPIO_PM_TO_SYS(23), "ext_3p3v", 0),
GPIO_VREG(EXT_MPP8, "ext_mpp8", "ext_mpp8_en",
- PM8921_MPP_PM_TO_SYS(8), NULL),
+ PM8921_MPP_PM_TO_SYS(8), NULL, 0),
GPIO_VREG(EXT_SATA_PWR, "ext_sata_pwr", "ext_sata_pwr_en",
/* FIXME: The GPIO port is changed from 4 to 3
* as SATA_PWR_EN conflicts with PCIE_PWR_EN.
@@ -588,20 +590,22 @@ apq8064_gpio_regulator_pdata[] __devinitdata = {
*/
#if defined(CONFIG_FB_MSM_LVDS_OPTRONICS)
PM8921_MPP_PM_TO_SYS(4), "ext_3p3v", 1),
-#else
- PM8921_MPP_PM_TO_SYS(3), "ext_3p3v", 1),
#endif
+ GPIO_VREG(EXT_SATA_PWR, "ext_sata_pwr", "ext_sata_pwr_en",
+ PM8921_MPP_PM_TO_SYS(3), "ext_3p3v", 1),
};
struct gpio_regulator_platform_data
mpq8064_gpio_regulator_pdata[] __devinitdata = {
- GPIO_VREG(AVC_1P2V, "avc_1p2v", "avc_1p2v_en", SX150X_GPIO(4, 2), NULL),
- GPIO_VREG(AVC_1P8V, "avc_1p8v", "avc_1p8v_en", SX150X_GPIO(4, 4), NULL),
+ GPIO_VREG(AVC_1P2V, "avc_1p2v", "avc_1p2v_en",
+ SX150X_GPIO(4, 2), NULL, 0),
+ GPIO_VREG(AVC_1P8V, "avc_1p8v", "avc_1p8v_en",
+ SX150X_GPIO(4, 4), NULL, 0),
GPIO_VREG(AVC_2P2V, "avc_2p2v", "avc_2p2v_en",
- SX150X_GPIO(4, 14), NULL),
- GPIO_VREG(AVC_5V, "avc_5v", "avc_5v_en", SX150X_GPIO(4, 3), NULL),
+ SX150X_GPIO(4, 14), NULL, 0),
+ GPIO_VREG(AVC_5V, "avc_5v", "avc_5v_en", SX150X_GPIO(4, 3), NULL, 0),
GPIO_VREG(AVC_3P3V, "avc_3p3v", "avc_3p3v_en",
- SX150X_GPIO(4, 15), "avc_5v"),
+ SX150X_GPIO(4, 15), "avc_5v", 0),
};
/* SAW regulator constraints */